@@ -1,6 +1,6 @@
-use std::process::Command;
-use std::fs;
 use crate::error::Result;
+use std::fs;
+use std::process::Command;
 
 fn replace(path: &str, find: &str, replace: &str) -> Result<()> {
     let temp = fs::read_to_string(path)?;
@@ -12,19 +12,27 @@ fn replace(path: &str, find: &str, replace: &str) -> Result<()> {
 
 pub fn new_plugin(name: String, git_url: String, git_branch: String) -> Result<()> {
     crate::update_std::check_std_installed()?;
-    
+
     println!("Creating plugin...");
-    let status =
-        Command::new("git")
-            .args(&[
-                "clone", "-b", &git_branch, "--single-branch", &git_url, &name
-            ])
-            .stdout(std::process::Stdio::piped())
-            .status()
-            .unwrap();
-    
+    let status = Command::new("git")
+        .args(&[
+            "clone",
+            "-b",
+            &git_branch,
+            "--single-branch",
+            &git_url,
+            &name,
+        ])
+        .stdout(std::process::Stdio::piped())
+        .status()
+        .unwrap();
+
     if status.success() {
-        let paths = &["Cargo.toml", "src/lib.rs", ".github/workflows/rust_build.yml"];
+        let paths = &[
+            "Cargo.toml",
+            "src/lib.rs",
+            ".github/workflows/rust_build.yml",
+        ];
 
         for path in paths {
             replace(&format!("{}/{}", name, path), "skyline_rs_template", &name)?;
@@ -34,4 +42,4 @@ pub fn new_plugin(name: String, git_url: String, git_branch: String) -> Result<(
     }
 
     Ok(())
-} 
+}
